==> cds-services-impl-1.18.3-sources.jar: com/sap/cds/services/impl/utils/NameOnlyCdsEntity.java <==
/**************************************************************************
 * (C) 2019-2021 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.utils;

import java.util.Optional;
import java.util.stream.Stream;

import com.sap.cds.ql.cqn.CqnSelect;
import com.sap.cds.reflect.CdsAction;
import com.sap.cds.reflect.CdsAnnotation;
import com.sap.cds.reflect.CdsElement;
import com.sap.cds.reflect.CdsEntity;
import com.sap.cds.reflect.CdsFunction;
import com.sap.cds.reflect.CdsParameter;

public class NameOnlyCdsEntity implements CdsEntity {

	private final String entityName;

	public NameOnlyCdsEntity(String entityName) {
		this.entityName = entityName;
	}

	@Override
	public CdsElement getElement(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Optional<CdsElement> findElement(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public CdsElement getAssociation(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Optional<CdsElement> findAssociation(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Stream<CdsElement> elements() {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getQualifiedName() {
		return entityName;
	}

	@Override
	public Stream<CdsAnnotation<?>> annotations() {
		throw new UnsupportedOperationException();
	}

	@Override
	public boolean isAbstract() {
		throw new UnsupportedOperationException();
	}

	@Override
	public boolean isView() {
		throw new UnsupportedOperationException();
	}

	@Override
	public boolean isProjection() {
		throw new UnsupportedOperationException();
	}

	@Override
	public Optional<CqnSelect> query() {
		throw new UnsupportedOperationException();
	}

	@Override
	public Stream<CdsParameter> params() {
		throw new UnsupportedOperationException();
	}

	@Override
	public Stream<CdsAction> actions() {
		throw new UnsupportedOperationException();
	}

	@Override
	public CdsAction getAction(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Optional<CdsAction> findAction(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Stream<CdsFunction> functions() {
		throw new UnsupportedOperationException();
	}

	@Override
	public CdsFunction getFunction(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Optional<CdsFunction> findFunction(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public <T> Optional<CdsAnnotation<T>> findAnnotation(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getName() {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getQualifier() {
		throw new UnsupportedOperationException();
	}

}

==> cds-services-impl-1.34.7-sources.jar: com/sap/cds/services/impl/utils/NameOnlyCdsEntity.java <==
/**************************************************************************
 * (C) 2019-2022 SAP SE or an SAP affiliate company. All rights reserved. *
 **************************************************************************/
package com.sap.cds.services.impl.utils;

import java.util.Optional;
import java.util.stream.Stream;

import com.sap.cds.ql.cqn.CqnSelect;
import com.sap.cds.reflect.CdsAction;
import com.sap.cds.reflect.CdsAnnotation;
import com.sap.cds.reflect.CdsElement;
import com.sap.cds.reflect.CdsEntity;
import com.sap.cds.reflect.CdsFunction;
import com.sap.cds.reflect.CdsParameter;
import com.sap.cds.reflect.CdsStructuredType;

public class NameOnlyCdsEntity implements CdsEntity {

	private final String entityName;

	public NameOnlyCdsEntity(String entityName) {
		this.entityName = entityName;
	}

	@Override
	public CdsElement getElement(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Optional<CdsElement> findElement(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public CdsElement getAssociation(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Optional<CdsElement> findAssociation(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Stream<CdsElement> elements() {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getQualifiedName() {
		return entityName;
	}

	@Override
	public Stream<CdsAnnotation<?>> annotations() {
		throw new UnsupportedOperationException();
	}

	@Override
	public boolean isAbstract() {
		throw new UnsupportedOperationException();
	}

	@Override
	public boolean isView() {
		throw new UnsupportedOperationException();
	}

	@Override
	public boolean isProjection() {
		throw new UnsupportedOperationException();
	}

	@Override
	public Optional<CqnSelect> query() {
		throw new UnsupportedOperationException();
	}

	@Override
	public Stream<CdsParameter> params() {
		throw new UnsupportedOperationException();
	}

	@Override
	public Stream<CdsAction> actions() {
		throw new UnsupportedOperationException();
	}

	@Override
	public CdsAction getAction(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Optional<CdsAction> findAction(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Stream<CdsFunction> functions() {
		throw new UnsupportedOperationException();
	}

	@Override
	public CdsFunction getFunction(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public Optional<CdsFunction> findFunction(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public <T> Optional<CdsAnnotation<T>> findAnnotation(String name) {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getName() {
		throw new UnsupportedOperationException();
	}

	@Override
	public String getQualifier() {
		throw new UnsupportedOperationException();
	}

	@Override
	public <S extends CdsStructuredType> S getTargetOf(String path) {
		throw new UnsupportedOperationException();
	}

}
